==> civicrm_5.22.1%2Bdfsg1.orig.tar.xz: civicrm/release-notes/5.22.1.md <==
# CiviCRM 5.22.1

Released February 18, 2020.

- **[Synopsis](#synopsis)**
- **[Bugs resolved](#bugs)**
- **[Credits](#credits)**
- **[Feedback](#feedback)**

## <a name="synopsis"></a>Synopsis

| *Does this version...?*                                         |         |
|:--------------------------------------------------------------- |:-------:|
| Fix security vulnerabilities?                                   |   no    |
| Change the database schema?                                     |   no    |
| Alter the API?                                                  |   no    |
| Require attention to configuration options?                     |   no    |
| Fix problems installing or upgrading to a previous version?     | **yes** |
| Introduce features?                                             |   no    |
| **Fix bugs?**                                                   | **yes** |

## <a name="bugs"></a>Bugs resolved

* **_Advanced Search_: Fix filtering by the "Active period" of a relationship ([dev/core#1592](https://lab.civicrm.org/dev/core/issues/1592): [#16535](https://github.com/civicrm/civicrm-core/pull/16535))**
* **_Dedupe_: Fix error when processing dedupe rules with custom data ([dev/core#1595](https://lab.civicrm.org/dev/core/issues/1595), [dev/core#1597](https://lab.civicrm.org/dev/core/issues/1597): [#16558](https://github.com/civicrm/civicrm-core/pull/16558))**
* **_CiviContribute_: Fix error when donor chooses to make one-time donation ([dev/core#1588](https://lab.civicrm.org/dev/core/issues/1588): [#16532](https://github.com/civicrm/civicrm-core/pull/16532))**
* **_CiviMail_: Fix error in certain advanced reports ([dev/core#1551](https://lab.civicrm.org/dev/core/issues/1551): [#16534](https://github.com/civicrm/civicrm-core/pull/16534))**
* **_Search Builder_: Fix filtering by "join date" of a membership ([dev/core#1602](https://lab.civicrm.org/dev/core/issues/1602): [#16578](https://github.com/civicrm/civicrm-core/pull/16578))**
* **_Upgrade_: Fix error involving managed entites ([dev/core#1498](https://lab.civicrm.org/dev/core/issues/1498): [#16521](https://github.com/civicrm/civicrm-core/pull/16521))**

## <a name="credits"></a>Credits

This release was developed by the following authors and reviewers:

Wikimedia Foundation - Eileen McNaughton; mclarke; Team Expansion - Greg
Harris; Lighthouse Design and Consulting - Brian Shaughnessy; John Kyle
Cronan; JMA Consulting - Seamus Lee; iXiam - César Ramos, Luciano Spiegel;
Ian Wilson; Freeform - Stephanie Gray Devapp - Adam Kwiatkowski Coop
SymbioTIC - Mathieu Lutfy; CiviCoop - Jaap Jansma; campaignrep; Caltha -
Tomasz Pietrzkowski; benmoreassynt Artful Robot - Rich Lott; Anthony Borrow;
Agileware - Justin Freeman;

## <a name="feedback"></a>Feedback

These release notes are edited by Tim Otten and Andrew Hunt.  If you'd like to
provide feedback on them, please login to https://chat.civicrm.org/civicrm and
contact `@agh1`.

==> civicrm_5.24.6%2Bdfsg1.orig.tar.xz: civicrm/release-notes/5.23.4.md <==
# CiviCRM 5.23.4

Released March 24, 2020.

- **[Synopsis](#synopsis)**
- **[Bugs resolved](#bugs)**
- **[Credits](#credits)**
- **[Feedback](#feedback)**

## <a name="synopsis"></a>Synopsis

| *Does this version...?*                                         |         |
|:--------------------------------------------------------------- |:-------:|
| Fix security vulnerabilities?                                   |   no    |
| Change the database schema?                                     |   no    |
| Alter the API?                                                  |   no    |
| Require attention to configuration options?                     |   no    |
| Fix problems installing or upgrading to a previous version?     |   no    |
| Introduce features?                                             |   no    |
| **Fix bugs?**                                                   | **yes** |

## <a name="bugs"></a>Bugs resolved

** **_Various_: Fix malformed URLs when CMS root is a subdirectory ([dev/joomla#26](https://lab.civicrm.org/dev/joomla/issues/26): [#16887](https://github.com/civicrm/civicrm-core/pull/16887))**

## <a name="credits"></a>Credits

This release was developed by the following authors and reviewers:

Tadpole Collective - Kevin Cristiano; Stephen Palmstrom; Squiffle Consulting - Aidan
Saunders; Nicol Wistreich; JMA Consulting - Seamus Lee; howardshand; CiviCRM - Tim Otten;
Andy Burns; Andrew Thompson

## <a name="feedback"></a>Feedback

These release notes are edited by Tim Otten and Andrew Hunt.  If you'd like to
provide feedback on them, please login to https://chat.civicrm.org/civicrm and
contact `@agh1`.
